function s = KubSplines(ti,data,typ,prt,dyrnd)
%-------------------------------------------------------------
% Kubische Splines
% Eingabe:
% data  - Datenpunkte
% ti    - Argument fr Interpolation 
% typ   - 1: natrliche Splines
% typ   - 2: Splines mit vorgegebenen Randableitungen (Hermite)
% typ   - 3: Periodische Splines
% typ   - 4: not-a-knot Splines
% prt   - 1 Grafik, 0 keine Grafik 
% dyrnd - Ableitung am Rand als Vektor [y0' yn']
% Ausgabe:
% Interpolierte Werte
%-------------------------------------------------------------
if nargin < 5
   dyrnd = [0 0];
end
if ischar(data)
   in = load(data);
else
   in = data;
end
[m ~] = size(in);
t = in(:,1);
y = in(:,2);
d = zeros(1,m);
h = zeros(1,m-1);
mue = zeros(1,m);
lambda = zeros(1,m);
% Schrittweitenvektor
for j=1:m-1
   h(j+1) = t(j+1)-t(j);
end;
for j=2:m-1
    mue(j) = h(j)/(h(j) + h(j+1));
    lambda(j) = 1 - mue(j);
    d(j) = (6/(h(j)+h(j+1)))*(((y(j+1)-y(j))/h(j+1))-((y(j)-y(j-1))/h(j)));
end;
A = diag(2*ones(1,m))+diag(lambda(1:m-1)',1)+diag(mue(2:m)',-1);
weiter = 1;
switch typ
case 1    % natrliche Randbedingungen
     %durch Initialisierung bereits vorgegeben
case 2    % Hermite Randbedingungen
     A(1,2) = 1;
     A(m,m-1) = 1;
     d(1)=(6/h(2))*((y(2)-y(1))/h(2)-dyrnd(1));
     d(m)=(6/h(m))*(dyrnd(2)-(y(m)-y(m-1))/h(m));
case 3    % Periodische Randbedingungen
     A(1,2) = 0;
     A(1,m) = -2;
     d(1) = 0;
     A(m,1) = h(2)/(h(2)+h(m));
     A(m,m-1) = h(m)/(h(2)+h(m));
     d(m) = (6/(h(2)+h(m)))*(((y(2)-y(1))/h(2))-((y(m)-y(m-1))/h(m)));
case 4    % not-a-knot Randbedingungen
     A(1,1) = 2;
     A(1,2) = -2*(h(2)+h(3))/h(3);
     A(1,3) = 2*h(2)/h(3);
     A(m,m-2) = 2*h(m)/h(m-1);
     A(m,m-1) = -2*(h(m)+h(m-1))/h(m-1);
     A(m,m) = 2;    
otherwise
     disp('Fehler: Falsche Typangabe.');
     weiter = 0;
end
if weiter == 1 
   M = A\d';
   s = zeros(1,length(ti));
   for k = 1:length(ti)
       j = 1;
       for j = 1:(m-1)
           if (ti(k)>= t(j)) && (ti(k) <= t(j+1))
              s(k) = ((M(j+1)-M(j))/(6*h(j+1)))*(ti(k)-t(j))^3 + 0.5*M(j)*(ti(k)-t(j))^2 +...
                     (((y(j+1)-y(j))/h(j+1))-(h(j+1)/6)*(2*M(j)+M(j+1)))*(ti(k)-t(j))+y(j); 
           end;
       end; 
   end;
   if prt == 1 
      hold on
      plot(in(:,1),in(:,2),'.r','MarkerSize',15);
      plot(ti,s,'-b');
   end;
end;
