function y = FourierReihe(func,xi,L,n)
%----------------------------------------------------------
% Partialsumme Sn der Fourier-Reihe einer Funktion
% mit Periode 2L
%
% Eingabe:
% func - Funktion als String mit Array-Operatoren mit x 
%        als Variable
% xi   - Argument (auch Vektor)
% L    - Periode 2L
% n    - Anzahl Summanden der Partialsumme
% Ausgabe:
% y - y = Sn(x)
%----------------------------------------------------------
m = length(xi);
%Eingabe der Funktion---
fin = inline(func,'x');
f = @(x) fin(x);
i = 1:1:n; 
fcos = @(x) fin(x).*cos(i.*pi.*x/L);
fsin = @(x) fin(x).*sin(i.*pi.*x/L);
%------------------------
a02 = double((1/L)*quad(f,-L,L))/2;
if n == 0
   y = repmat(a02,1,m);
else
  
   ai = (1/L)*quadv(fcos,-L,L);
   bi = (1/L)*quadv(fsin,-L,L);
   y = repmat(a02,1,m) + sum((repmat(ai,m,1).*cos(xi'*i*pi/L))')+...
                         sum((repmat(bi,m,1).*sin(xi'*i*pi/L))');
end;
S = @(x) (a02 + sum(ai.*cos(x*i*pi/L)) - fin(x)).^2;
L2_Abstand = (quadv(S,-L,L))^0.5