function u = FourierWelle(xi,ti,f,g,c,L,n,prt)
%----------------------------------------------------------
% Approximierende Partialsumme Sn der Fourier-Lsung der
% Wellengleichung
%
% Eingabe:
% xi    - Ort (auch Vektor)   
% ti    - Zeit (auch Vektor) 
% f     - Auslenkung zur Zeit t = 0 als String mit 
%         Array-Operatoren und x als Variable
% g     - Anfangsgeschwindigkeit als String mit 
%         Array-Operatoren und x als Variable
% c     - Konstante
% L     - Intervall [0;L]
% n     - Anzahl Summanden der Partialsumme
% prt   - 1 Grafikausgabe
% Ausgabe:
% u     - u = Sn(x,t)
%----------------------------------------------------------
mx = length(xi);
mt = length(ti);
u = zeros(mx,mt);
fin = inline(f,'x');
gin = inline(g,'x');
i =1:1:n;
fsin = @(x) fin(x).*sin(i.*pi.*x/L);
gsin = @(x) gin(x).*sin(i.*pi.*x/L);
Bi = double((2/L)*quadv(fsin,0,L)); 
Ci = double((2/(c*pi))*quadv(gsin,0,L))./i;
for j=1:mt
    for k=1:mx
        u(k,j) = sum(sin(i*xi(k)*pi/L).*(Bi.*cos(i*ti(j)*c*pi/L) + Ci.*sin(i*ti(j)*c*pi/L)));  
    end;
end;
if prt == 1 
   [TI,XI] = meshgrid(ti,xi); 
   mesh(XI,TI,u);
end;
   