%------------------------------------------------------------------------
% Finites Differenzenverfahren fr die stationre Wrmeverteilung
% in einer homogenen Platte mit konstanten Randtemperaturen
%
% Parameter:
% N ->  Integer, die Gitterweite ist h = 1/(N+1)
% TO -> Oberere Randtemperatur der Platte
% TR -> Rechte Randtemperatur der Platte
% TL -> Linke Randtemperatur der Platte
% TU -> Untere Randtemperatur der Platte
% 0 ->  Nur die inneren Gitterpunkte werden geplottet
% 1 ->  Temperaturverteilung mit linearer Approximation wird geplottet
% Beispiel: FDMv2(99,200,100,150,0,1) 
%------------------------------------------------------------------------
function [X,Y,L]=FDMv2(N,TO,TR,TL,TU,approx)
Gitterweite = 1/(N+1)
%Erzeugen der Koeffizientenmatrix A
B=-diag(ones(1,N)*4)+diag(ones(1,N-1),1)+diag(ones(1,N-1),-1);
sparse(B);
C=sparse(N^2);
for k = 0:N-1
    C(k*N+1:k*N+N,k*N+1:k*N+N) = B; 
end
clear i j k B;
A = C + diag(sparse(ones(1,N^2-N)),N);
A = A + diag(sparse(ones(1,N^2-N)),-N);
%Erzeugen der rechten Seite b
d = zeros(N);
d(1,1) = -TL - TU;
d(N,1) = -TR - TU;
d(1,N) = -TL - TO;
d(N,N) = -TR - TO;
for i = 2:N-1
  d(i,1) = -TU;
end
for i = 2:N-1
  d(i,N) = -TO;
end
for i = 2:N-1
  d(N,i) = -TR;
end
for i = 2:N-1
  d(1,i) = -TL;
end
c = d';
b = c(:);
clear c d i;
sparse(b);
%Lsen des Gleichungssystems mit dem Backslash-Operator
u = A\b;
clear A b;
%Der N^2-dimensionale Lsungsvektor wird in eine Matrix L geschrieben.
%Die Eintrge dieser Matrix geben die Gitterpunkte im Inneren der Platte
%wieder. Die LsungsMatrix wird dann mit dem Befehl mesh visualisiert.
L = reshape(u,N,N);
clear u;
%Grafische Ausgabe der Lsung
x = linspace(1/(N+1),N/(N+2),N);
y = linspace(1/(N+1),N/(N+2),N);
[X,Y] = meshgrid(x,y);
switch approx 
  case 0
       figure,mesh(X,Y,L);
  case 1 
       L=L';
       figure,linapp_paint(50,N,L,TO,TR,TL,TU);
  case 2
       figure,mesh(X,Y,L);
       L=L';
       figure,linapp_paint(50,N,L,TO,TR,TL,TU); 
end;
   