function ShanSincRep(fName,omega,L,T,N);
%-------------------------------------------------------------------------
% Shannon Theorem mit sinc Reproduktion
% Eingabe:
% fName - Funktion mit Periode L des analogen Signals
% omega - omega = L*Fm
% L - Periode
% T - Interval [0;T]
% N - Anzahl Teilintervalle der Lnge h = T/N
%-------------------------------------------------------------------------
h = T/N;
delta_t = h
Fm = omega/L
fs = 1/h
Nyquist = 1/(2*h)
x = 0:h:T;
f = inline(fName);
y = f(x);
%--------------------------------------------------------------------------
subplot(4,1,1);
title('Analoges Signal');
hold on;
grid on;
plot(x,y,'o','LineWidth',1,'MarkerEdgeColor','k','MarkerFaceColor','r', ...
    'MarkerSize',2);
axis([0 T -max(y)-1 max(y)+1]);
in = 0:0.01:T;
plot(in,f(in));
%--------------------------------------------------------------------------
subplot(4,1,2);
title('FFT Betrge');
hold on;
ck = abs(fft(y,N));
freq = 0:1/T:(N-1)/(2*T);
ck = ck(1:N/2);
axis([0 N/(2*T) 0 max(ck)+1]);
index = find(ck == max(ck));
HPeriode = num2str(freq(index))
plot(freq(index),ck(index),'ro', 'MarkerSize',10);
stem(freq,ck,'fill','-','Color','b','Markersize',4,'LineWidth',1);
%--------------------------------------------------------------------------
subplot(4,1,3);
title('Einfache Reproduktion');
hold on;
axis([0 T -max(y)-0.5 max(y)+0.5]);
plot(x,y,'-r','LineWidth',1,'MarkerEdgeColor','k','MarkerFaceColor',...
    'k','MarkerSize',2);
stem(x,y,'fill','-','Color','b','Markersize',4,'LineWidth',1);
%-------------------------------------------------------------------------
subplot(4,1,4);
title('Reproduktion durch approximierende sinc-Funktionen');
hold on;
t = 0.01:0.01:T;
k = 0:1:N*N-1;
km = 1:1:N*N-1;
yp = repmat(y,1,N);
yp = yp(1:N*N);
ypm = yp;
ypm(1) = [];
o = ones(1,N*N);
om = ones(1,N*N-1);
r = zeros(1,length(t));
for m = 1:length(t)
    r(m) = sum(yp.*sinc(t(m)*fs*o - k)) + sum(ypm.*sinc(t(m)*fs*om + km));
end
axis([0 T -max(r)-0.5 max(r)+0.5]);
plot(t,r);
stem(x,y,'fill','Color','r','Markersize',4,'LineWidth',1);