%------------------------------------------------------------------------
% kf-value Plotter for steel grades
%
%Input: fun - Function e.g. func100cr6 
%         var - Variables e.g. {'phi'} or {'phi' 'phip'}
%         con - Constants e.g. {'T'} or {'T' 'phi'}
%         val - Value of the constants [900] or [2.5 3]
%         dom - Interval of the variables e.g. [0;2.5] or [0 0;2.5 3.5]
%                    if there are two variables 
%         dat - data file of the measured data (optional)
%                  -> for plotting the measured points
%                  -> if '' then no plot of the measured points
%-------------------------------------------------------------------------
function funcplotkf(fun,var,con,val,dom,dat)
%function handle
eval(strcat('bfc = @',fun,';')); 
%No plot of measured data if mdp == 0
mdp = 0;
if dat ~= ' '
   mdata = load(dat);
   mdp = 1;
end
lvar = length(var);
if lvar == 1
   min12 = min(dom);
   max12 = max(dom);
   if strcmp(char(var(1)),'phi') == 1
      if strcmp(char(con(1)),'T') == 1
        T = val(1);
         phip = val(2);
      else
         T = val(2);
         phip = val(1);
      end
      if mdp == 1 
         j = 0;
         for i = 1:length(mdata)
             if (mdata(i,3) == T) & (mdata(i,1) == phip)
                j = j + 1;
                in(j,1) = mdata(i,2);
                in(j,2) = mdata(i,4);
             end
         end
         if j == 0 
            disp(' ');
            disp('Error -> No measured values found for given constants');
            disp(' ');
            disp('Hint -> Change values of constants');
            disp(['Current values: ',char(con(1)),' = ',num2str(val(1)),...
                 '; ',char(con(2)),' = ',num2str(val(2))]); 
            return
         end
         inmin = min(in);
         inmax = max(in);
         a = min(min12(1),inmin(1));
         b = max(max12(1),inmax(1));
     else
         a = min12(1);
         b = max12(1);
      end
      t = (a: 0.01: b);
      [k,l]=size(t);      
      for p = l:-1:1
          fdat(p) = bfc(T,t(p),phip);
      end
      if mdp == 1
         plot(in(:,1),in(:,2),'o',t,fdat,'-')
      else
          plot(t,fdat,'-')
      end
      grid on
      xlabel('phi');
      ylabel('kf');
      s = ['kf-values for ',char(con(1)),' = ',num2str(val(1))...         
                ,'; ',char(con(2)),' = ',num2str(val(2))];
      title(s);
.
.
.
elseif lvar == 2
   min12 = min(dom);
   max12 = max(dom);
  .
  .
  .
  elseif strcmp(char(con(1)),'T') == 1
      T = val(1);
      j = 0;
      if mdp == 1
         for i = 1:length(mdata)
             if mdata(i,3) == T
                j = j + 1;
                in(j,1) = mdata(i,2);
                in(j,2) = mdata(i,1);
                
in(j,3) = mdata(i,4);
             end
         end
         if j == 0 
            disp(' ');
            disp('Error -> No measured values found for given constant');
            disp(' ');
            disp('Hint -> Change value of the constant');
            disp(['Current value: ',char(con(1)),' = ',num2str(val(1))]); 
            return
         end
         inmin = min(in);
         inmax = max(in);
      end
      if strcmp(char(var(1)),'phi') == 1
         if mdp == 1
            a = min(min12(1),inmin(1));
            b = max(max12(1),inmax(1));
            c = min(min12(2),inmin(2));
            d = max(max12(2),inmax(2));
         else
            a = min12(1);
            b = max12(1);
            c = min12(2);
            d = max12(2); 
         end
      else
         disp(' ');
         disp('Error -> phi must be the first variable');
         disp(' ');
         return
      end
      hold on
      if mdp == 1
        plot3(in(:,1),in(:,2),in(:,3),'.','MarkerSize',15);
      end
      q = 70;
      x = linspace(a,b,q);
      y = linspace(c,d,q);
      [X,Y] = meshgrid(x,y);
      Z = zeros(q);
      for j=1:q
          for i=1:q
              Z(j,i) = bfc(T,x(i),y(j));
          end
      end
   end
   surf(X,Y,Z)
   shading interp;
   colormap default;
   %surf(X,Y,Z,'FaceColor','red','EdgeColor','none')
   %camlight left; lighting phong
   xlabel(char(var(1)));
   ylabel(char(var(2)));
   zlabel('kf');
   s = ['kf-values for ',char(con(1)),' = ',num2str(val(1))];
   title(s);
   view(39,29);
   grid on
   hold off
end
