%-------------------------------------------------------------------------
% Testing Iteration Methods solving linear Systems Ax = b
%
% Input:  meth - 1 Gauss-Seidel Index, 2 Gauss-Seidel Matrix
%                       3 SOR - GS, 4 Jacobi, 5 SOR - Jacobi 
%                       6 Conjugate Gradients 
%                       7 Preconditioned Conjugate Gradients (PCG)
%            tol - Tolerance
%            N - max. Iterations
%            w - Relaxation-Parameter omega
%-------------------------------------------------------------------------
function it_method_test(meth,tol,N,w)
%The first 20,000 prime numbers
p = primes(224740);
n = length(p);
d = [];
for i = 14:-1:0
    d = [d,-2^i];
end
d = [d,0];
for i = 0:14
    d = [d,2^i];
end
O = ones(n,15);
B(1:n,1:15) = O; B(:,16) = p'; B(1:n,17:31) = O;
% Generating a 20,000 x 20,0000 Matrix having the first 20,000
% prime numbers as diagonal
A = spdiags(B,d,n,n);
b = 100*ones(n,1);
b = sparse(b);
x0 = b;
tic;
switch meth
case 1
      disp(' ')  
      disp('Method: Gauss-Seidel (Index)')
      u = gs_ind(A,b,x0,tol,N);
case 2
      disp(' ')  
      disp('Method: Gauss-Seidel (Matrix)')
      u = gs_mat(A,b,x0,tol,N);
case 3
      disp(' ')  
      disp('Method: SOR -> Gauss-Seidel (Matrix)')
      disp(' ')
      display(['Relaxation: ',num2str(w)])
      u = SOR(A,b,x0,tol,N,w);
case 4
      disp(' ')  
      disp('Method: Jacobi (Matrix)')
      u = jacobi(A,b,x0,tol,N);
case 5
      disp(' ')  
      disp('Method: SOR - Jacobi (Matrix)')
      disp(' ')
      display(['Relaxation: ',num2str(w)])
      u = SOR_jacobi(A,b,x0,tol,N,w);
case 6
      disp(' ')  
      disp('Conjugate Gradients Squared Method')
      % Using MATLAB built-in-function pcg
      u = pcg(A,b,tol,N);
      Time = toc
case 7
      disp(' ')  
      disp('Preconditioned Conjugate Gradients Squared Method')
      % Using MATLAB built-in-function pcg with preconditioner M
      M = diag(diag(A));
      u = pcg(A,b,tol,N,M);
      Time = toc
end 
