% Function-File: NewtonHom 
% Embedded Newton method in N Dimensions.
% Input:  fName  - String (Name) of the function-file 
%           dfName   - String (Name) of the jacobian-file
%           v              - Start vector e.g. [0;...;-1]
%           tol            - Tolerance
%           m             - Partition
%-------------------------------------------------------
function u = NewtonHom(fName,dfName,xc,tol,m)
 
%-- Init
iter = 0;
disp(' ');
disp('Start embedded Newton iteration');
tic;
%--Iterations
l = length(xc);
x0 = xc;
for i = 1:m 
     ti = i/m;
     fc = ones(1,l);
     f0   = feval(fName,x0);
     while norm(fc) > tol + eps;
         fc   = feval(fName,xc);
         fc   = fc + (ti - 1)*f0;
         dfc  = feval(dfName,xc);
         s    = -dfc\fc;              
         xc   = xc+s;
         iter = iter+1;
     end
     x0 = xc; end
disp(' ');
s = sprintf('Iterations: %d',iter);
disp(s);
u = xc;
Time = toc 