% Function-File: NewtonNVA 
% Simplified Newton method in N Dimensions.
% using an estimation of the jacobian
% Input:  fName  - String (Name) of the function-file 
%            xc     - Start vector e.g. [0;...;-1]
%            h      - delta x
%            tol    - Tolerance
%-------------------------------------------------------
function u = NewtonNVA(fName,xc,h,tol)
%-- Init
iter = 0;
disp(' ');
disp('Start simplified Newton iteration with estimation of the jacobian');
tic;
n = length(xc);
e = zeros(n,1);
%Generating the approx. matrix for the jacobian
for i = 1:n
    e(i) = 1;
    dfc(:,i)  = (1/h)*(feval(fName,xc+h*e)-feval(fName,xc));
    e(i) = 0;
end;
%--Iterations
fc = ones(1,n);
while norm(fc) > tol + eps;
   fc   = feval(fName,xc);
   xs    = -dfc\fc;             
   xc   = xc+xs;
   iter = iter+1;
end
disp(' ');
s = sprintf('Iterations: %d',iter);
disp(s);
u = xc;
Time = toc
