% Function-File: ContMeth 
% Continuation method in N Dimensions.
% Input:  fName   - String (Name) of the function-file 
%         dfName  - String (Name) of the jacobian-file
%         a,b     - Left and right boundary of the intervall [a;b]
%         x0      - Start vector e.g. [0;...;-1]
%         tol     - Tolerance
%         h       - Step width
%         kopt    - Optimal iterations for the corrector
%                   (if kopt = 0 then no correction of the step width)
%         pl      - Plot the solution set (only for n <= 2)
%                   (0 -> no plot, 1 -> plot)
function u = ContMeth(fName,dfName,a,b,x0,tol,h,kopt,pl)
%-- Init
iter = 0;
cnt = 0;
j = 0;
lj = a;
xc = x0;
n = length(xc);
s = strcat('f = @',fName,';');
eval(s);
s = strcat('df = @',dfName,';');
eval(s);
disp(' ');
disp('Start Continuation method');
tic;
%--Iterations
while lj <= b
  k = 0;
  fc = ones(n,1);
  %--Corrector-Step -> Newton method
  while norm(fc) > tol + eps
    fc   = f(xc,lj);
    dfc  = df(xc,lj);
    xs    = -dfc\fc;              
    xc   = xc+xs;
    k    = k + 1;
  end
  cnt = cnt + k;
  iter = iter + 1;
%--Predictor-Step
  %Classical predictor -> xc  
  %--Step-Width
  if kopt ~= 0  
     ro = kopt/k;
     ro = max(min(ro,2),0.5);
     h = h*ro;
  end
  if h < eps 
     break;
  end
  %--Output
  u(iter,:) = [lj;xc];
   lj = lj + h;
end
disp(' ');
s = sprintf('Corrector steps: %d',iter);
disp(s);
s = sprintf('Total number of iterations: %d',cnt);
disp(s);
if iter > 0 
   s = sprintf('Average of iterations per Corrector step: %d ',round(cnt/iter)); 
   disp(s);
end
%Graphic
if n > 2 
   pl = 0
end
if pl == 1
   if n == 1  
      plot(u(:,1),u(:,2),'--rs','LineWidth',1,'MarkerFaceColor','g','MarkerSize',3);
   else
      plot3(u(:,1),u(:,2),u(:,3),'-bs','LineWidth',1,'MarkerFaceColor','g','MarkerSize',2);
      grid on; axis square;
   end
end
Time = toc