% Function-File: ContMethEP 
% Continuation method in N Dimensions.
% Input:  fName   - String (Name) of the function-file 
%           dfName  - String (Name) of the jacobian-file with resp. to x
%           dflName - String (Name) of the partial derivative with 
%                             resp. to lambda 
%            a,b        -  Left and right boundary of the intervall [a;b]
%            x0         -  Start vector e.g. [0;...;-1]
%            tol         -  Tolerance
%            h           -  Step width
%            kopt      -  Optimal iterations for the corrector
%                            (if kopt = 0 then no correction of the step width)
%            pl          -  Plot the solution set (only for n <= 2)
%                            (0 -> no plot, 1 -> plot)
%-------------------------------------------------------
function u = ContMethEP(fName,dfName,dflName,a,b,x0,tol,h,kopt,pl)
%-- Init
iter = 0; cnt = 0; j = 0; lj = a; xc = x0; n = length(xc);
s = strcat('f = @',fName,';'); eval(s);
s = strcat('df = @',dfName,';'); eval(s);
s = strcat('dfl = @',dflName,';'); eval(s);
disp(' ');
disp('Start Continuation method');
tic;
%--Iterations
while lj <= b
  k = 0;
  fc = ones(n,1);
  %--Corrector-Step -> Newton method
  while norm(fc) > tol + eps
     fc   = f(xc,lj);
     dfc  = df(xc,lj);
     xs   = -dfc\fc;              
     xc   = xc+xs;
     k     = k + 1;
  end 
  cnt = cnt + k;
  iter = iter + 1;
  %--Output
  u(iter,:) = [lj;xc];
  %--Predictor-Step using EULER-Predictor
  dflc = dfl(xc,lj);
  zs   = -dfc\dflc;
  xc   = xc + h*zs; 
  %--Line Search (Step Width)
  if kopt ~= 0  
     ro = kopt/k;
     ro = max(min(ro,2),0.5);
     h = h*ro;
  end
  if h < eps 
     break;
  end
  lj = lj + h;
end
disp(' ');
s = sprintf('Corrector steps: %d',iter);
disp(s);
s = sprintf('Total number of iterations: %d',cnt);
disp(s);
if iter > 0 
   s = sprintf('Average of iterations per Corrector step: %d ',round(cnt/iter)); 
   disp(s);
end
%--Graphic