% Curve pursuit method 
%---------------------------------------------------------------------------------------
% Input:  fName   - String (Name) of the function-file 
%            dfName  - String (Name) of the jacobian-file with resp. to x
%            a,b          - Left and right boundary of the intervall [a;b]
%            x0            - Start vector e.g. [0;...;-1]
%            tol            - Tolerance
%            h             - Step width
%            kopt        - Optimal iterations for the corrector
%                              (if kopt = 0 then no correction of the step width)
%            pl            -  Plot the solution set (only for n <= 2)
%                              (0 -> no plot, 1 -> plot)
%            pre         -  Predictor 'E' -> EULER 'S' -> Secants
%           maxits     - Maximum of iterations (default 20000)
%------------------------------------------------------------------------------------------
function u = CurvePursuit(fName,dfName,a,b,x0,tol,h,kopt,pl,pre, maxits)
%-- Init
if nargin < 11
   maxits = 20000;
end
iter = 0; cnt = 0; lj = a; xc = [x0;a]; n = length(x0);
xa = xc; ha = h;
eval(strcat('f = @',fName,';'));
eval(strcat('df = @',dfName,';'));
disp(' ');
if pre == 'E'
   disp(['Start Curve Pursuit (EULER) -> ',char(datestr(now))]');
else
   disp(['Start Curve Pursuit (Secants) -> ',char(datestr(now))]'); 
end;
tic;
%--Iterations
imax = 1;
while lj <= b
  k = 0;
  fc = ones(n,1);
  %--Corrector-Step -> Newton method
while norm(fc) > tol + eps
    fc   = f(xc);
    dfc  = df(xc);
    xs   = (dfc*dfc')\fc;
    xs   = dfc'*xs;
    xc   = xc-xs;
    k    = k + 1;
    if norm(xs) < eps 
       break;
    end
    if k > 1000
       break;
    end
  end
  cnt = cnt + k;
  iter = iter + 1;
  %--Output
  lj = xc(n+1);
  x = xc([1:n]);
  u(iter,:) = [lj x];
  %--Predictor-Step 
  if pre == 'E'
     %EULER 
     zs   = null(dfc); %Der Tangentenvektor wird mit der MATLAB-Funktion null berechnet,
                       %die Richtung wird nicht angepasst.
  end
  else
     %Secants 
     zs   = (xc-xa)/ha;
  end;
  xa   = xc;
  xc   = xc + h*zs;
  %xc   = xc + h;
  %--Line Search (Step Width)
  ha = h;
.
.
.
(weiter wie in Function-File ContMeth.m) 