% Non Linear Curve Fitting using GAUSS-NEWTON-Method
%
% Input: data      - File of the measured data
%           fName   - String (Name) of the function-file 
%           dfName - String (Name) of the jacobian-file of the 
%                           residue function r with resp. to x
%            xc         - Start vector
%            tol         - Tolerance
%            prt         - 1 Plot of the fitting curve and the data points
%                           0 no plot
%        
% Output: R2  - Rsquared
%            Coefficients x1,...,xn of the modell function
%            Plot of the fitting curve and the data points if prt = 1
%--------------------------------------------------------------------------
function [x,r] = NLA(data,fName,dfName,xc,tol,prt)
disp(' ');
disp(['Non Linear Curve Fitting - Start -> ',char(datestr(now))]);
disp(' ');
if ischar(data)
   in = load(data);
else
   in = data;
end
[m q] = size(in);
%--Data points
for k = 1:(q-1)
  t(:,k) = in(:,k);
end
y = in(:,q);
%--Init
iter = 0;
fc   = feval(fName,t,xc,y);
dfc  = feval(dfName,t,xc);
%--Iterations
while norm(fc) > tol + eps
  xs   = -dfc\fc;   %Lsen des linearen Problems in MATLAB mit dem \-Operator
  xc   = xc+xs;
  if norm(xs) < eps 
     break;
  end
  fc   = feval(fName,t,xc,y);
  dfc  = feval(dfName,t,xc);
  iter = iter + 1;
  if iter > 1000
     break;
  end
end
C = '';
i = 1;
for i = 1:q
    v1 = num2str(i);
    v2 = num2str(xc(i));
    if i == 1
       C = strcat('x',v1,' =  ',v2);
    else
       C = strcat(C,'; x',v1,' = ',v2);
     end
end
%--Print the modell function
text = textread(strcat(fName,'.m'),'%s','delimiter','\n','whitespace','');
[Q, P] = size(text);
i = 1;
for k = 1:(q-1)
  t(:,k) = in(:,k);
end
y = in(:,q);
%--Init
iter = 0;
fc   = feval(fName,t,xc,y);
dfc  = feval(dfName,t,xc);
%--Iterations
while norm(fc) > tol + eps
  xs   = -dfc\fc;              
  xc   = xc+xs;
  if norm(xs) < eps 
     break;
  end
  fc   = feval(fName,t,xc,y);
  dfc  = feval(dfName,t,xc);
  iter = iter + 1;
  if iter > 1000
     break;
  end
end
C = '';
i = 1;
for i = 1:q
    v1 = num2str(i);
    v2 = num2str(xc(i));
    if i == 1
       C = strcat('x',v1,' =  ',v2);
    else
       C = strcat(C,'; x',v1,' = ',v2);
     end
end
%--Print the modell function
text = textread(strcat(fName,'.m'),'%s','delimiter','\n','whitespace','');
[Q, P] = size(text);
i = 1;
for i = 1:Q
    j = strmatch('%',text(i));
    k = strmatch('function',text(i));
    if isempty(j) && isempty(k)
        disp('Model function: ');
        disp(text(i)); 
    end
end
disp(['Parameter: ',C]);
%--RSquare
fdata = [];
[Q,P] = size(in);
fdata = -feval(fName,t,xc,0);  
y = in(:,P);
sf = sum((fdata - y).^2);
mf = sum((y).^2);
r2 = 1-sf/mf;
v = num2str(r2);
display(' ');
display(['RSquared: ', v])
display(' ');
%--Output
x = xc;
r = r2;
%Plot the points of the dataset and the best fitting curve
if P > 3 
   prt = 0
end
if prt == 1 
   %Generate points for plotting using the best fitting curve
   %Find the Minimum and Maximum of the t-values of input data
   min12 = min(in);
   max12 = max(in);
   hold on
  
if P == 2 
      plot(in(:,1),in(:,2),'-rs','LineWidth',1,'MarkerFaceColor','g','MarkerSize',2);
      plot(in(:,1),fdata,'-','MarkerSize',7);
   end
   if P == 3
      plot3(in(:,1),in(:,2),in(:,3),'.','MarkerSize',15);
      ezmesh(fdata,[min12(1),max12(1),min12(2),max12(2)],70);
   end
   title(['RSquared: ', v]);
   shading interp;
   colormap default;
   grid on
   hold off
end