%Zeros of a function by Newton method (uses Symbolic Toolbox)
%
%Input:  func  - String of the function e.g. 'x^2-2x-3'
%           x0     - Start value 
%           tol     - Tolerance 
%           st      - 0 or 1 -> Shows iteration-steps 
%           N      - Max. iter. 
%Output:  approx. zero 
%
%Example: Newton('x^2-2*x-3',2,eps,0,100)
function z = Newton(func,x0,tol,st,N)
%define the inline-function 
f = inline(func);
df = inline(char(diff(func)));
iter = 0;
disp(' ');
s = sprintf('%s %f','Tolerance = ',tol + eps);
disp(s);
disp(' '); 
if st ~= 0
   disp(' '); 
   s = sprintf('%s       %s           %s','Iteration','x','-f/df');
   disp(s);
   s = sprintf('%s','-----------------------------------------------');
   disp(s);
   s = sprintf('%d          %f        %f',iter,x0,-f(x0)/df(x0));
   disp(s);
end
s = 1;
xk = x0;
while abs(s) > tol + eps 
  if iter > N  1
     break;
  end
  s = -f(xk)/df(xk);
  xk = xk + s;
  iter = iter + 1; 
  %-Output if steps = 1
  if st ~= 0 
     disp(sprintf('%d          %f       %f',iter,xk,-f(xk)/df(xk)));                   
  end
end 
if st ~= 0
   disp(' ');
   disp(sprintf('%s %f','x* = ',xk));                                                              
   disp(' ');
end
disp(' ');
z = xk; 
