% Fixpoint iteration using an estimation for q
% 
% Input:  fName  - String (Name) of the function-file 
%            v           - Start vector e.g. [0;...;-1]
%            tol         - Tolerance
%-------------------------------------------------------
function u = BanachE(fName,v,tol) 
%-- Initialization
iter = 0;
xc0 = v;
xc1 = feval(fName,xc0);
ncon = 0;
qk = 0.5;
%--Iterations
disp(' ');
disp('Start fixpoint iteration with estimated q');
while (qk/(1-qk))*norm(xc0-xc1) > tol + eps*max(norm(xc0),norm(xc1))
   xc2 = feval(fName,xc1);
   qk = norm(xc2-xc1)/norm(xc1-xc0);
   xc0 = xc1;
   xc1 = xc2;
   iter = iter+1; 
   if qk >= 1 
      sprintf('STOP: Function is not contractive!');
      ncon = 1;
      break;
   end  
end
if ncon = 0
   disp(' ');
   s = sprintf('Iterations: %d',iter);
   disp(s);
   u = xc1;
end