% Function-File: BroydenN 
% Broyden method in N Dimensions.
% Input:  fName  - String (Name) of the function-file 
%           dfName - String (Name) of the jacobian-file
%            v           - Start vector e.g. [0;...;-1]
%            tol         - Tolerance
%----------------------------------------------------------------
function u = BroydenN(fName,dfName,v,tol)
 
disp(' ');
disp('Start Broyden iteration');
%--Init
tic;
iter = 0;
xc = v;
fc = feval(fName,xc);
Bc = feval(dfName,xc);
 
%--Iterations
while norm(fc) > tol + eps;
   s    = -Bc\fc;
   xc   = xc+s;
   f    = fc;
   fc   = feval(fName,xc);
   yc   = fc-f;
   Bc   = Bc+((yc-Bc*s)*s')/(s'*s);
   iter = iter+1;
end
disp(' ');
s = sprintf('Iterations: %d',iter);
disp(s);
u = xc;
Time = toc
